import setuptools

#with open("readme.md", "r") as fh:
    #long_description = fh.read()

setuptools.setup(
    name="TempConverter",
    version="1.0",
    author="Akash",
    author_email="akash9129@gmail.com",
    description="A small package to convert temperature",
    long_description='A Package to convert temperature',
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


# __main__.py

import sys

def c2f(n):
    """
    celsius to fahrenheit
    """
    try:
        f = (n * 1.8) + 32
        return f
    except TypeError:
        n = "Enter a number"
        return n

def f2c(n):
    """
    fahrenheit to celsius
    """
    try:
        c = (n - 32) / 1.8
        return c
    except TypeError:
        n = "Enter a number"
        return n

def add_temp(n):
    a = f2c(n)
    b = c2f(n)
    r = a + b
    return r

    

 